#
# spec file for package python-jenkins-job-builder
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2014 Thomas Bechtold <thomasbechtold@jpberlin.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-jenkins-job-builder
Version:        1.6.1
Release:        3.1
Summary:        Manage Jenkins jobs with YAML
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/openstack-ci/jenkins-job-builder
Source:         https://pypi.io/packages/source/j/jenkins-job-builder/jenkins-job-builder-%{version}.tar.gz
# PATCH-FIX-UPSTREAM 0001-Fix-timeout-wrapper-version-detection.patch -- https://review.openstack.org/387799
Patch1:         0001-Fix-timeout-wrapper-version-detection.patch
BuildRequires:  python-pbr
BuildRequires:  python-setuptools-git
Requires:       python-PyYAML
Requires:       python-jenkins >= 0.4.8
Requires:       python-pbr >= 1.0.0
Requires:       python-six >= 1.5.2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Jenkins Job Builder takes simple descriptions of Jenkins jobs in YAML format,
and uses them to configure Jenkins. You can keep your job descriptions in human
readable text format in a version control system to make changes and auditing
easier. It also has a flexible template system, so creating many similarly
configured jobs is easy.

%prep
%setup -q -n jenkins-job-builder-%{version}
%patch1 -p1

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc ChangeLog README.rst LICENSE AUTHORS
%{python_sitelib}/*
%{_bindir}/jenkins-jobs

%changelog
* Tue Oct 18 2016 tbechtold@suse.com
- Add 0001-Fix-timeout-wrapper-version-detection.patch (bsc#1019600)
* Fri Jul 15 2016 tbechtold@suse.com
- Switch to pypi.io as Source url
* Thu Jul 14 2016 tbechtold@suse.com
- update to 1.6.1:
  * Catch OSError when renaming and try to remove the destination file first
  * Fix broken skip-push on docker-build-publish
  * Update Sonatype CLM for CI plugin
  * Remove obsolete tools script
  * Adds support multijob support to the CopyArtifact plugin
  * Allow testing non-default configs with complex definitions
  * Python 3.x tempfile requires unicode
  * Prevent corruption of cache by using atomic update
  * Add support for Jenkins OpenStack Cloud Plugin
  * Add support for http request plugin
  * Add test and update documentation for mailer plugin
  * XUnitDotNetTestType xUnit publisher support
  * Update Plot plugin
  * docs: add missing :jenkins-wiki: macro to CMake builder
  * Add deadline option for build-timeout plugin
  * Fix typo in doc of workspace-cleaner wrapper
  * builders: update cmake to match CMake plugin versions 2.x
  * Compatibility support for older maven project plugins
  * Update workspace-cleanup to support newer options
  * Update Google Cloud Storage publisher
  * Update deprecated from version to 1.5.0
  * Add support for URL scm plugin
  * Serialize combine-queued-commits for git-revision
  * Fix Generic Artifactory repository key selection options
  * Add Build Name Setter to Builders
  * Support test trend graph in Build Flow Test Aggregator
  * Update Hipchat support to work w/all versions
  * Job DSL target needs to be plural, not singular
  * Add support for OWASP Dependency-Check Plugin
  * Removing perModuleEmail paramater management
  * Add trigger for RabbitMQ trigger module
  * Change documentation to install from pypi
  * Add support for docker builder plugin
  * Add Promoted Build parameter
  * Be able to handle Slack Plugin 2.0 configuration
  * Convert remaining Jenkins wiki URLs to sphinx roles
  * Update Urls for redirects and broken
  * Fix CFP configuration for >=2.10.0
  * Fix building (make) in 'doc' directory
  * Clarify exception message for missed trigger properties
  * Tidy up True/False and use better exceptions
  * Replace deprecated assertEquals with assertEqual
  * cmd: Add a config file fallback to the user's home directory
  * email_ext publisher: Improve docstring wording
  * email publisher: Clarify format of recipients list in docstring
  * Add user/password command line argument
  * multijob: add support for "ALWAYS" continuation condition
  * Revert "Allow using lockfile per jenkins master"
  * Allow using lockfile per jenkins master
  * Added possibility to exclude project combinations
  * Add PLAIN default for branch|project-compare-type
  * Add support for disable-strict-forbidden-file-verification
  * upd google-cloud-storage plugin support
  * slack notifications on repeated failure
  * Allow to omit list of projects in Gerrit trigger config
  * Fix 3 doc warnings
  * Take parameter order from yaml in trigger_parameterized_builds
  * Use provided mapping object type instead OrderedDict
  * Preserve data type when constructing new container
  * add support for node-parameters option for multijob builder
  * Update docs to include installation via pypi
  * Adding the build-discarder property
  * Partial support Yaml Axis Plugin
  * Added github-pull-request-merge publisher
  * Add helper function to convert xml
  * gerrit trigger: Fix doc on topics
  * Fix issue with non-ascii characters in get_job_md5
  * Document template variable default values
  * Allow id's for different templates to follow same naming
  * Description Setter Plugin support as builder
  * SCM repo: add show-all-changes option
  * SCM repo: add trace option
  * SCM repo: add no-tags option
  * SCM repo: add reset-first option
  * SCM repo: add depth option
  * Allow null values for log-text
  * SCM repo: add force-sync option
  * add reference-repo option to scm git submodule
  * Add new parameter for warnings publisher
  * Remove ordereddict support from py26
  * Fix delete-all command to include all job types
  * Fixed downstream_ext comparison conditions
  * Fix default result for reverse trigger
  * Add doxygen builder support
  * Add script-type to env-script wrapper
  * Fix ircbot's any-failure parameter documentation
  * Small typo fix
  * Add Docker Custom Build Environment Plugin support
  * Adding support for maven-metadata-plugin
  * Add matrixOptions to throttle properties module
  * Add hue-light plugin support
  * Add Test Selector Plugin support
  * * Added support for the Jenkins Slack plugin
  * gitlab trigger: Support new "addCiMessage" flag
  * Wrap stdout object only once with wrap_stream
  * Add more details about Emotional Jenkins plugin to docs
  * Add support for credentials properties in authorization matrix
  * Remove linkcheck from sphinx builders list in config
  * Add separate linkcheck env and allow dev to select builder
  * Remove Python 2.6 compatibility patch
  * Updated to support changes to openshift pipeline plugin
  * Warn only once for masked definitions
  * Add support for default-excludes in archives
  * Reorder imports to match hacking guidelines
  * Adding Build Keeper plugin
  * Clarify 'trigger-parameterized-builds' description
  * Allow multiple credentials-binding entries
  * Adding setup of credentialsId in stashNotifier
  * Modifying .gitignore file to add .idea folder
  * Implement bzr SCM module
  * Add support for matrices' subset in multijobs
  * Fix docstring of downstream-ext publisher
  * Adding a new project parameter on multijob
  * Added "Downstream build of" build selector
  * Add support for "tox" builder
  * Order component retrieval to favour user defined
  * Infer and build entry points from component modules
  * Standardize docstrings for properties module
  * Deprecated tox -downloadcache option removed
  * Add support for cucumber reports plugin
  * delivery-pipeline: support task description template
  * document workspace-cleanup wrapper "dirmatch" default
  * builders: fix mavenName sorting with py35
  * publishers: iterate over copy of checkstyle data
  * Standardize builders docstrings and remove '\'
  * Add support of 'somewhereElse' value to Copy to slave plugin
  * Revert "Add support for "tox" builder"
  * Correct the entry points of cucumber-testresult
  * Fix pollscm backwards compatiblity
  * Add support for "tox" builder
  * Document the new {template-name} variable
  * Add parallelization options
  * Add regexp option to conditional publisher
  * Add support for the RunDeck plugin
  * Added support for the workflow job type
  * Add template-name as a variable that can be used in a template
  * Add 'do-not-fingerprint' to 'copyartifact' builder
  * Debug message leads to (n*m) log growth
  * Option to mark build as unstable in PostBuildScript publisher
  * Allow deep formatting of macro parameters
  * publishers: xunit doesn't accepts integers as threshold
  * Fix the wrong info in docs about default slave param
  * add support for NodeJS Plugin
  * Add support for Rebuild Plugin
  * Remove deprecated getChildren() usage
  * Copy config files tree
  * useMatrixChild support in parameterized trigger
  * Add support for runscope plugin
  * Add flatten and encryption support to s3 publisher
  * cmd.py: tweak plugin information querying logic
  * Make git.timeout parameter set clone timeout too
  * [BUGFIX] Add missing "strExclusionSet" element when using "exclusionValues"
  * Fix the artifactory plugin docs due to extra whitespace
  * quick-start: Fix the configuration file argument to read "--conf"
  * Adding support for monitoring files using FSTrigger Plugin
  * fix for python 3, decode job output
  * Fix update after deleting all jobs
  * Allow raw XML at project top-level
  * Fix delete-all command on python 3
  * Wrap file objects with codecs to handle unicode
  * Made a common helper function - convert_mapping_to_xml
  * builder.py: fix potential race condition
  * Implements: additions for OS3 plugin entry points in builders and scm
  * setup.cfg: py26 is no longer supported
  * Revert "Support for Shiningpanda's Tox Builder"
  * Capture logs with FakeLogging Fixture
  * Support for Shiningpanda's Tox Builder
  * Distinguish kept jobs and unmanaged jobs when skipping removal
  * Add control over more settings of github pull request builder plugin
  * Update sphinx to be compatible with readthedocs.org
  * fix default handling of script-file-path
  * Allow save to be called more than once
  * Allow JJB to set connection timeout to jenkins server
  * Separate out custom yaml tags into separate classes
  * Support copyartifact build selector param
  * Add support for Artifactory plugin
  * Add new parameters to Build Blocker example / test
  * support for the phabricator plugin
  * List conditions for trigger-parameterized-builds
  * Added hipchat publisher for HipChat plugin >=0.1.9
  * Added gitlab plugin
  * Add support for whitesource plugin
  * Add Trigger that supports the Jenkins "BitBucket plugin"
  * Boolean parameters and more options in Parameterized Trigger Plugin
  * Add support for the CucumberTestResult plugin
  * Add support for blocking-level and queue scanning to Build Blocker plugin
  * Add Ability to use the AWS Cloudformation Plugin
- Adjust Requires
- Remove 0001-Add-marker-to-only-need-ordereddict-for-py2.6.patch
  Applied upstream.
* Sun Nov  1 2015 tbechtold@suse.com
- set correct Name which is python-jenkins-job-builder
* Fri Oct 30 2015 tbechtold@suse.com
- add 0001-Add-marker-to-only-need-ordereddict-for-py2.6.patch
  Only require ordereddict with python 2.6
* Fri Oct 30 2015 tbechtold@suse.com
- update to 1.3.0:
  * rm argparse from requirements.txt
  * Update tox with supported python versions
  * Reformat docstrings for SCM
  * BugFix: Target field in Job-DSL plugin was not being populated
  * correct sidebar link url & name
  * adding support for android emulator
  * Add support for forbidden file paths in gerrit trigger
  * Validate and set compare types in gerrit trigger
  * Use correct element name in scoverage module
  * Enhance macro expansion documentation
  * Add a JJB quick start guide
  * Allow whitespace to be significant
  * Ensure tests run with ConfigParser object
  * Add trigger-with-no-params for join-trigger
  * Support for externaljob project-type for monitoring external jobs
  * Adds onlyIfSuccessful to ArtifactArchiver publisher
  * Document that jjb supports json job definitions
  * Support disable-publisher and both-html-text content-type in email-ext
  * Add a requirements file for readthedocs
  * Fix two typos and Fix readability
  * Adding publisher support to join-trigger plugin
  * Replace open() with io.open() and force 'utf-8'
  * Adding support for IvyTrigger Plugin
  * Reformat xUnit publisher function and docstring help
  * Find module for exceptions raised from gen_xml
  * configure git PathRestriction as an extension
  * Avoid parallel builder tests creating cache dir
  * Adding Flowdock as a supported publisher
  * Support for more conditions type in conditions-buildstep plugin
  * Support for more configurable options in sonar publisher
  * Support for more extensions and options in Git plugin
  * Add Google Cloud Storage Plugin support
  * Support for repo-depth and ignore-externals in svn plugin
  * general: add support for childCustomWorkspace
  * Adding support for Sidebar Plugin
  * scm svn: add support for viewvc-url
  * Added support for groovy script trigger
  * Add deprication warning in documentation
  * Improvement in the Credentials Binding Plugin
  * Removed unnecessary parameter from delete_old_jobs
  * Adding support for javadoc plugin
  * Support for health-scale-factor in junit plugin
  * xunit: Add support for Google Test
  * Exclude .test directory from pep8 check
  * Support anonymous credentials for Jenkins plugin info query
  * Add Disable Failed Job Plugin support
  * Add Parameterized Remote Trigger Plugin support
  * Add support for the Naginator Plugin
  * Update xml-summary publisher
  * Adding support for LiveScreenshot Plugin
  * Support for more options in gerrit plugin and doc cleanup
  * Test update command with --delete-old option
  * Support for post-step-run-condition in Maven projects
  * Add support to reverse trigger for job list
  * Update 'timeout' wrapper module
  * Validate the use of `[]` as an `scm` value
  * Change zuul-cloner parameters
  * Adding unittest to ownership property
  * Support for image gallery publisher
  * requirements: pin pbr>=0.8.2,<2.0
  * Fall back to git clone if zuul-cloner not available
  * Support for more configurable options in Plots Plugin
  * Adding Maven3 Builder Targets
  * Adding disableArchiveOutput option in Robot Framework Plugin
  * Adding builder for SSH plugin
  * Add support for keep-records parameter for plots-plugin
  * Enable tests of builder object
  * Support use of lists in trigger-build publisher
  * Make include_path deterministic
  * Add support for Clang Scan-Build plugin version 1.5
  * Replace ci.o.o links with docs.o.o/infra
  * Adding tests surrounding handling of defaults values
  * Improvements in the Maven Plugin
  * Add logstash publisher
  * Add support for Gatling plugin
  * Test with LANG set to UTF-8
  * Allow use of aliases defined previously inside included files
  * Query all jobs once
  * Revert "Added parallelization options"
  * Move writexml fix for older minidom to same module as caller
  * Adding support for Beaker Builder Plugin
  * add support for measurement plots plugin to junit publisher
  * Add support for 'raw' to inject direct xml to job configs
  * Added parallelization options
  * hipchat bug fix
  * Accept list of hipchat rooms
  * Add support for Display Upstream Changes Plugin
  * Remove YamlParser from jenkins_jobs.builder
  * Remove superfluous calls to matches()
  * Add support for Sonatype CLM plugin
  * Support for Xvfb plugin
  * Add InvalidAttributeError and MissingAttributeError
  * Add support to CFP in builders sections
  * Allow inclusion of multiple files
  * Added gerrit trigger missing options
  * Add support for hipchat notifier 0.1.8
  * Support the use of lists in trigger-build builder
  * zuul: drop notifications
  * Only query jenkins plugins if config provided
  * Log info about updated and deleted jobs
  * added support for NodeLabel parameter in trigger-builds
  * Add ability to configure releaseEnvVar for maven-deploy publisher
  * Initial work for supporting downstream-ext
  * Add support for Scoverage plugin
  * Added support for JClouds Blobstore
  * Fixed broken links in documentation
  * publishers: groovy-postbuild changes between 1.x & 2.x
  * Fix jenkins-job-builder-compare-xml job by using zuul-cloner
  * Added possibility to use non-existent keys
  * Stop mkdir output on each job write
  * Treat non-existant output files as empty files
  * Convert all inline publisher examples to tests
  * Adding more configurable options in Notifications plugin
  * Add FindBugs support to Publishers
  * Add checking of multijob phase condition
  * Add missing '
  * Pass through git revision to triggered jobs
  * Add support to configure boolean parameter in PBT
  * Add 'Job Log Logger' wrapper
  * Add support of multiple credentials for ssh-agent-credentials wrapper
  * Remove nonexistent servername and cleanup build publisher
  * updated conditional_publisher to support plugin changes
  * fix test in include-raw-escape001.yaml
  * Add support for Sonar analysis builder
  * Log the job name info when running test mode
  * Add FindBugs plugin support
  * Add tests for yaml anchor behaviour
  * Fix typo in format string
  * Consolidate CFP settings into a common function
  * Add support for Config File Provider to Maven Project module
  * Support additional features in Build Flow project
  * Add detailed call out about the SCP plugin
  * Add support to customize trigger-builds block thresholds
  * Support hacking module <= 0.10.1
  * Use sphinx extlinks to shorten links to Jenkins wiki
  * Check external documentation links are valid
  * Remove unnecessary warning message
  * Add 'Build Flow Test Aggregator' publisher
  * The email publisher needs a list of recipients
  * Add support for github commit status pending
  * Fix bug in template job yaml expansion
  * Add support for xvnc
  * Add Job DSL Plugin
  * Fix broken link on documentation
  * Add 'readable-message' parameter to gerrit trigger
  * xUnit publisher: add option to skip if there are no tests files
  * Enable whitelisted-orgs-as-admins for ghprb trigger
  * Adding coverage.py publisher for ShiningPanda Plugin
  * Add details to credentials param in scm docs
  * Support excludes when recursively processing paths
  * Change test folder name to 'fixture' for consistency
  * Fix wrong casing in JDKAxis <name> tag
  * Add 'last-completed' to copyartifact 'which-build' values
  * adds support for not condition in conditional_step
  * Lazy load plugin list
  * Use open() instead of file()
  * BugFix: pollscm trigger docs & unittests
  * Add support for new patchset-created exclude fields
  * Depend on python-jenkins 0.4.1 or later
  * Implement recursive search for test fixtures
  * Fix NullPtr issue in ownership props
  * Add plugins_info to module registry object
  * Fix formatting for inclusion of README.rst
  * Update SCM Git Clean configuration to use new extensions style
  * Update SCM Wipe workspace to use extensions style
  * Provide a more complete yaml reference in the docs for CMake module
  * xUnit publisher: add test-time-margin extra config option
  * xUnit publisher: add support to CTest
  * Provide info on number of jobs processed for test, update and delete-all
  * Fix invalid link to jenkins puppet module
  * Interpolate params inside of params
  * Add test for name defaults overridden by template
  * Use mock in a Python 3.4 compatible way
  * Add support for JDK axis
  * Enable whitelisting branches with pull request builder
  * builders: add cmakebuilder plugin support
  * Add 'Enable condition' support to MultiJob builder
  * Skip duplicate input files
  * Update and clean up docs
  * Add support for 'All Nodes For Label Factory'
  * Update git-submodule configuration to new extension style
  * add support for EnvInject mask password params option
  * Add support for M2 repository cleanup plugin
  * Allow multiple node selection for 'node' parameter
  * Move project matrix documentation into a test
  * fix project matrix doc rendering
  * Report source of duplicate entries where possible
  * Add DRY publisher
  * add support for python and tox matrix project axis
  * Add example to demonstrate flow plugin for job-template
  * update jjb info for clarity
- Adjust Requires according to requirements.txt
* Wed Mar 11 2015 tbechtold@suse.com
- update to 1.1.0:
  * deprecate postbuildscript onsuccess and onfailure parameter names
  * Add 'node' parameter to 'parameters'
  * Add support for Gerrit Trigger Comment Contains Expression
  * Allow multiple comment-added events in gerrit trig
  * Add Mercurial plugin feature to jenkins-job-builder
  * adding support for the custom tools plugin
  * fix typo, must be 'classifier' to appear on pypi.python.org
  * Workflow documentation is now in infra-manual
  * Fix the postbuildscript documentation
  * URL in Maven deploy is an optional field
  * Reorganize tests/cmd
  * Make the recipients argument optional
  * Add examples for 'predefined-parameters'
  * Add parameter to trigger_parameterized_builds
  * Refactor checkstyle publisher
  * Document node parameter usage with matrix projects
  * Add support for Config File Provider to Maven Project module
  * adds safe-output to email-ext in publishers.py
  * add support to git for changelog against branch
  * Add perlcritic capability to violations method
  * Move extended-choice support to parameters module
  * include publisher.xunit test as doc
  * Add support for the Jenkins Clang Scan-Build publisher plugin
  * Add MongoDB plugin support
  * add test for globbed parameters feature
  * Add fingerprint parameter to archive publisher
  * Add support for the matrix-combinations plugin
  * report exactly which jobs will be deleted
  * Add support for the S3 Publisher plugin
  * Switched documentation to point to storyboard
- update Requires
* Mon Apr 21 2014 thomasbechtold@jpberlin.de
- Initial packaging for jenkins-job-builder.
